<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://tarlorand.com
 * @since             1.0.0
 * @package           Custom_Rss_Events_Reader_Lt
 *
 * @wordpress-plugin
 * Plugin Name:       Custom RSS Events Reader LT
 * Plugin URI:        https://tarlorand.com
 * Description:       Plugin used to fetch RSS feed with events and display in a custom format.
 * Version:           1.0.0
 * Author:            Lorand Tar
 * Author URI:        https://tarlorand.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       custom-rss-events-reader-lt
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-custom-rss-events-reader-lt-activator.php
 */
function activate_custom_rss_events_reader_lt() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-custom-rss-events-reader-lt-activator.php';
	Custom_Rss_Events_Reader_Lt_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-custom-rss-events-reader-lt-deactivator.php
 */
function deactivate_custom_rss_events_reader_lt() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-custom-rss-events-reader-lt-deactivator.php';
	Custom_Rss_Events_Reader_Lt_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_custom_rss_events_reader_lt' );
register_deactivation_hook( __FILE__, 'deactivate_custom_rss_events_reader_lt' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-custom-rss-events-reader-lt.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_custom_rss_events_reader_lt() {

	$plugin = new Custom_Rss_Events_Reader_Lt();
	$plugin->run();

}
run_custom_rss_events_reader_lt();
