<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://tarlorand.com
 * @since      1.0.0
 *
 * @package    Custom_Rss_Events_Reader_Lt
 * @subpackage Custom_Rss_Events_Reader_Lt/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Custom_Rss_Events_Reader_Lt
 * @subpackage Custom_Rss_Events_Reader_Lt/public
 * @author     Lorand Tar <tarlori@yahoo.com>
 */
class Custom_Rss_Events_Reader_Lt_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Custom_Rss_Events_Reader_Lt_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Custom_Rss_Events_Reader_Lt_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/custom-rss-events-reader-lt-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Custom_Rss_Events_Reader_Lt_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Custom_Rss_Events_Reader_Lt_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/custom-rss-events-reader-lt-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * [register_feed_events_shortcode description]
	 * @return [type] [description]
	 */
	public function register_feed_events_shortcode($atts)
	{
		$args = shortcode_atts( 
		    array(
		        'url'   => '',
		        'num'   => '10',
		    ), 
		    $atts
		);

		$url = $args['url'];
		$num = (int) $args['num'];

		if (empty($url)) return '';

		$html = '<section class="feed_events_lt" data-url="'.$url.'" data-num="'.$num.'"></section>';

		return $html;
	}

	/**
	 * [get_events_feed_lt description]
	 * @return [type] [description]
	 */
	public function get_events_feed_lt() {

		$url = (string) $_POST['url'];
		$num = (int) $_POST['num'];
		$html = $this->getFeedContent($url, $num);

		echo $html;

		die();
	}

	public function getFeedContent($url, $num)
	{
		$invalidurl = false;
		if(@simplexml_load_file($url)){
			$feeds = simplexml_load_file($url);
		} else {
			$invalidurl = true;
			$html .= "<p>Invalid RSS feed URL.</p>";
		}


		$i=0;
		if(!empty($feeds)){

			$site = $feeds->channel->title;
			$sitelink = $feeds->channel->link;

			$html .= '<ul>';
			foreach ($feeds->channel->item as $item) {

				$title = $item->title;
				$link = $item->link;
				$description = $item->description;
				$postDate = $item->pubDate;
				$pubDate = date('F d, Y h:i a',strtotime($postDate));


				if($i >= $num) break;

				$html .= '
				<li>
					<a class="" href="'.$link.'">'.$title.'</a>
				   	<span>'.$pubDate.'</span>
				</li>';

				$i++;
			}
			$html .= "</ul>";
		} else {
			if(!$invalidurl){
			 $html .= "<p>No item found</p>";
			}
		}

		return $html;
	}

}
